## Description

A summary of the pull request.

## Impact on users using Chronovoyage

A description of changes in specifications and user experience.

## Evidence of tests (such as operation of command, added testcases, behavior of built documentation, and so on)

Steps to reproduce:

1. Prepare ...
2. Migrate with ...
3. Table ... is created

Other cases ...
